@@ -13,5 +13,6 @@ read_text <- function(txt, delim = "\t", ...) {
     if (txt == "clipboard")
         txt <- readr::clipboard()
 
-    readr::read_delim(txt, delim = delim)
+    readr::read_delim(txt, delim = delim) %>%
+        dplyr::mutate_if(is.character, as.factor)
 }
